/* SPDX-License-Identifier: GPL-2.0 WITH Linux-syscall-note */

#ifndef _LINUX_VIRTIO_GPIO_H
#define _LINUX_VIRTIO_GPIO_H

#include <linux/types.h>

/* Virtio GPIO request types */
#define VIRTIO_GPIO_MSG_GET_NAMES		0x0001
#define VIRTIO_GPIO_MSG_GET_DIRECTION		0x0002
#define VIRTIO_GPIO_MSG_SET_DIRECTION		0x0003
#define VIRTIO_GPIO_MSG_GET_VALUE		0x0004
#define VIRTIO_GPIO_MSG_SET_VALUE		0x0005

/* Virtio GPIO message irq */
#define VIRTIO_GPIO_MSG_IRQ_MAP			0x0010
#define VIRTIO_GPIO_MSG_IRQ_UNMAP		0x0011

/* Possible values of the status field */
#define VIRTIO_GPIO_STATUS_OK			0x0
#define VIRTIO_GPIO_STATUS_ERR			0x1

/* Direction types */
#define VIRTIO_GPIO_DIRECTION_NONE		0x00
#define VIRTIO_GPIO_DIRECTION_OUT		0x01
#define VIRTIO_GPIO_DIRECTION_IN		0x02

/* Virtio GPIO command */
enum virtio_gpio_cmd {
	VIRTIO_GPIO_CMD_IRQ_SW,
	VIRTIO_GPIO_CMD_IRQ_MASK,
	VIRTIO_GPIO_CMD_IRQ_UNMASK,
	VIRTIO_GPIO_CMD_IRQ_SET_TYPE,
	VIRTIO_GPIO_CMD_IRQ_CLR,
};

struct virtio_gpio_event {
	__u32 type;
	__u32 value;
};

struct virtio_gpio_config {
	__u32 cmd;
	__u32 intr_status;
	__u16 ngpio;
	__u8 padding[2];
	__u32 gpio_names_size;
} __attribute__((packed));

/* Virtio GPIO Request / Response */
struct virtio_gpio_request {
	__u16 type;
	__u16 gpio;
	__u32 value;
};

struct virtio_gpio_response {
	__u8 status;
	__u8 value;
};

struct virtio_gpio_response_get_names {
	__u8 status;
	__u8 value[];
};

#endif /* _LINUX_VIRTIO_GPIO_H */

 
